@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
 our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -288,6 +288,12 @@ sub gen_cli_doc_data_from_meta {
                         # regular (positive sentence) summary
                         $opt->{summary} =
                             $rimeta->langprop({lang=>$lang}, 'summary.alt.bool.not');
+                    } elsif (defined $ospec->{is_neg}) {
+                        # for boolean option which we show the positive, show
+                        # the positive summary if available
+                        $opt->{summary} =
+                            $rimeta->langprop({lang=>$lang}, 'summary.alt.bool.yes') //
+                                $rimeta->langprop({lang=>$lang}, 'summary');
                     } elsif (($ospec->{parsed}{type}//'') eq 's@') {
                         # for array of string that can be specified via multiple
                         # --opt, show singular version of summary if available.
@@ -459,7 +465,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.16 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-04-02.
+This document describes version 0.17 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
